<?php

if (!function_exists('queryModels')) {
    function queryModels($modelName, $conditions = [], $pagination = null, $withRelations = [])
    {
        $modelClass = "App\\Models\\" . $modelName;

        if (!class_exists($modelClass)) {
            throw new Exception("Error: Model class '{$modelName}' not found.");
        }

        $model = new $modelClass;

        if (!method_exists($model, 'newQuery')) {
            throw new Exception("Error: Model '{$modelName}' does not support querying.");
        }

        $queryBuilder = $model->newQuery();

        if (!empty($withRelations)) {
            $queryBuilder->with($withRelations);
        }

        if(!is_null($conditions)){
            foreach ($conditions as $field => $value) {
                if (is_array($value)) {
                    $queryBuilder->where($field, $value[0], $value[1]);
                } else {
                    $queryBuilder->where($field, $value);
                }
            }
        }



        if ($pagination && is_array($pagination)) {
            $perPage = $pagination['perPage'] ?? 15;
            $page = $pagination['page'] ?? 1;
            return $queryBuilder->paginate($perPage, ['*'], 'page', $page);
        }
        return $queryBuilder->orderBy('id','DESC')->get();
    }
}

if (!function_exists('queryModelsOrders')) {
    function queryModelsOrders($modelName, $conditions = [], $pagination = null, $withRelations = [], $relationships = [])
    {
        $modelClass = "App\\Models\\" . $modelName;

        if (!class_exists($modelClass)) {
            throw new Exception("Error: Model class '{$modelName}' not found.");
        }

        $model = new $modelClass;

        if (!method_exists($model, 'newQuery')) {
            throw new Exception("Error: Model '{$modelName}' does not support querying.");
        }

        $queryBuilder = $model->newQuery();

        if (!empty($withRelations)) {
            $queryBuilder->with($withRelations);
        }

        if (!empty($relationships)) {
            foreach ($relationships as $relation => $callback) {
                $queryBuilder->whereHas($relation, $callback);
            }
        }

        if (!empty($conditions)) {
            foreach ($conditions as $field => $value) {

                if (is_array($value)) {
                    if (count($value) == 3) {
                        $queryBuilder->where($value[0], $value[1], $value[2]);

                    }
                } else {
                    $queryBuilder->where($field, $value);
                }
            }
        }

        if ($pagination && is_array($pagination)) {
            $perPage = $pagination['perPage'] ?? 15;
            $page = $pagination['page'] ?? 1;
            return $queryBuilder->paginate($perPage, ['*'], 'page', $page);
        }

        return $queryBuilder->orderBy('id', 'DESC')->get();
    }
}



if (!function_exists('get_models')){
    function get_models($models,$conditions = [])
    {
        $modelClass = "App\\Models\\" . $models;
        if (!$modelClass){
            throw new Exception("Error: Model class '{$models}' not found.");
        }
        $model = new $modelClass;
        $queryBuilder = $model->newQuery();
        if(!is_null($conditions)){
            foreach ($conditions as $field => $value) {
                if (is_array($value)) {
                    $queryBuilder->where($field, $value[0], $value[1]);
                } else {
                    $queryBuilder->where($field, $value);
                }
            }
        }

        return $queryBuilder->get();
    }
}

if (!function_exists('generateRandomString')){
    function generateRandomString($length = 10)
    {
        $characters = 'ABCDEFHIJKLMNOPQRSTUVWXYZ0123456789';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
}

